From 687400dd8221fcfc430d423168cd3ffb6a4ae74e Mon Sep 17 00:00:00 2001
From: dcc <dcc@163.com>
Date: Mon, 06 May 2024 17:42:35 +0800
Subject: [PATCH] 去掉马股,马来西亚,港股
---
src/page/newUser/index.vue | 72 ++++++++++++++++++++++-------------
1 files changed, 45 insertions(+), 27 deletions(-)
diff --git a/src/page/newUser/index.vue b/src/page/newUser/index.vue
index 0289d1b..85cee9b 100644
--- a/src/page/newUser/index.vue
+++ b/src/page/newUser/index.vue
@@ -33,24 +33,24 @@
<i @click="xy = !xy" class="iconfont xy"></i>
</div>
<div class="number-all">
- <showHide :text="userInfo.totalAssets" :flg="xy" />
+ <showHide :text="asstesAll" :flg="xy" />
</div>
</van-col>
</van-row>
<van-row style="margin-top: 18px">
- <div class="van-col van-col--8" style="margin-top: 10px">
- <div class="content-title DINPro">{{ $t("美股總資產") }}(USD)</div>
- <div>
- <div class="DINPro" style="font-size: 18px">
- <showHide :text="userInfo.usTotalAssets" :flg="xy" />
- </div>
+ <div
+ class="van-col van-col--12"
+ style="margin-top: 10px"
+ v-for="item in listAsstes"
+ :key="item.accectType"
+ >
+ <div class="content-title DINPro">
+ {{ item.title3 }}
+ ({{ item.symbolCode }})
</div>
- </div>
- <div class="van-col van-col--8" style="margin-top: 10px">
- <div class="content-title">{{ $t("馬股總資產") }}(USD)</div>
<div>
<div class="DINPro" style="font-size: 18px">
- <showHide :text="userInfo.masTotalAssets" :flg="xy" />
+ <showHide :text="item.availableBalance" :flg="xy" />
</div>
</div>
</div>
@@ -102,7 +102,7 @@
:name="item.title"
>
<ul class="money">
- <li>
+ <li style="text-align: left">
<div class="li-title">
{{ item.title1 }}({{ item.symbolCode }})
</div>
@@ -150,28 +150,40 @@
listAsstes: [
{
title: this.$t("美股資產"),
+ title3: this.$t("美股總資產"),
title1: this.$t("美股可用"),
title2: this.$t("美股冻结"),
accectType: "US",
symbol: "$",
symbolCode: "USD",
},
+ {
+ title: this.$t("印股資產"),
+ title3: this.$t("印股總資產"),
+ title1: this.$t("印股可用"),
+ title2: this.$t("印股冻结"),
+ accectType: "IN",
+ symbol: "₹",
+ symbolCode: "IND",
+ },
// {
// title: this.$t("印股資產"),
// title1: this.$t("印股可用"),
// title2: this.$t("印股冻结"),
// accectType: "IN",
// symbol: "RM",
// symbolCode: "MYR",
// },
- {
- title: this.$t("馬股資產"),
- title1: this.$t("馬股可用"),
- title2: this.$t("馬股冻结"),
- accectType: "MAS",
- symbol: "RM",
- symbolCode: "MYR",
- },
+ // {
+ // title: this.$t("港股资产"),
+ // title3: this.$t("港股總資產"),
+ // title1: this.$t("港股可用"),
+ // title2: this.$t("港股冻结"),
+ // accectType: "HK",
+ // symbol: "HK$",
+ // symbolCode: "HKD",
+ // },
],
active: this.$t("美股資產"),
name: "",
@@ -183,6 +195,7 @@
userInfo: [],
onlineService: "",
moneyList: [],
+ asstesAll: "0.00",
};
},
created() {
@@ -197,6 +210,7 @@
if (data.status === 0) {
// 判断是否登录
this.moneyList = data.data;
+ console.log(data.data)
data.data.map((item) => {
this.listAsstes.map((items) => {
if (item.accectType === items.accectType) {
@@ -209,7 +223,9 @@
}
});
});
- console.log(this.listAsstes);
+
+ const arr = data.data.filter((item) => item.accectType === "ALL");
+ this.asstesAll = arr[0].totalMoneyUSD;
}
},
tabsChange(e) {
@@ -301,7 +317,7 @@
},
async getUserInfo() {
// 获取用户信息
- let data = await api.getUserInfo();
+ let data = await api.getUserInfodata();
if (data.status === 0) {
// 判断是否登录
this.$store.commit("dialogVisible", false);
@@ -486,6 +502,8 @@
color: #2d2f3c;
}
.li-USDT {
+ min-width: 180px;
+ text-align: right;
font-style: normal;
font-weight: 500;
font-size: 0.37333rem;
@@ -988,4 +1006,4 @@
input[type="file"] {
display: none !important;
}
-</style>
\ No newline at end of file
+</style>
@@ -150,28 +150,40 @@
// {
- // title: this.$t("印股資產"),
- // title1: this.$t("印股可用"),
- // title2: this.$t("印股冻结"),
- // accectType: "IN",
+ // title: this.$t("馬股資產"),
+ // title3: this.$t("馬股總資產"),
+ // title1: this.$t("馬股可用"),
+ // title2: this.$t("馬股冻结"),
+ // accectType: "MAS",
// symbol: "RM",
// symbolCode: "MYR",
--
Gitblit v1.9.3